/*
  Copyright (c) 2016, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include <string>

#include <sys/statvfs.h>

#include "success_fail.hpp"

namespace StatVFS
{
  static
  inline
  bool
  readonly(const struct statvfs &st)
  {
    return (st.f_flag & ST_RDONLY);
  }

  static
  inline
  uint64_t
  spaceavail(const struct statvfs &st)
  {
    return (st.f_frsize * st.f_bavail);
  }

  static
  inline
  uint64_t
  spaceused(const struct statvfs &st)
  {
    return (st.f_frsize * (st.f_blocks - st.f_bavail));
  }
}
